@@ -3,9 +3,9 @@ from unittest import TestCase
 from piccolo.apps.user.tables import BaseUser
 from piccolo.columns.combination import WhereRaw
 from piccolo.query.methods.select import Avg, Count, Max, Min, Sum
+from tests.example_apps.music.tables import Band, Concert, Manager, Venue
 
 from ..base import DBTestCase, postgres_only, sqlite_only
-from ..example_app.tables import Band, Concert, Manager
 
 
 class TestSelect(DBTestCase):
@@ -13,7 +13,6 @@ class TestSelect(DBTestCase):
         self.insert_row()
 
         response = Band.select().run_sync()
-        print(f"response = {response}")
 
         self.assertDictEqual(
             response[0],
@@ -24,7 +23,6 @@ class TestSelect(DBTestCase):
         self.insert_row()
 
         response = Band.select(Band.name).run_sync()
-        print(f"response = {response}")
 
         self.assertDictEqual(response[0], {"name": "Pythonistas"})
 
@@ -65,6 +63,18 @@ class TestSelect(DBTestCase):
         )
         self.assertEqual(response, [{"name": "Pythonistas"}])
 
+        # check multiple arguments inside WHERE clause
+        response = (
+            Band.select(Band.name)
+            .where(Band.manager.id == 1, Band.popularity == 500)
+            .run_sync()
+        )
+        self.assertEqual(response, [])
+
+        # check empty WHERE clause
+        response = Band.select(Band.name).where().run_sync()
+        self.assertEqual(response, [{"name": "Pythonistas"}])
+
     @postgres_only
     def test_where_like_postgres(self):
         """
@@ -150,7 +160,6 @@ class TestSelect(DBTestCase):
             "%ist%",
             "%IST%",
         ):
-
             self.assertEqual(
                 Band.select(Band.name)
                 .where(Band.name.ilike(ilike_query))
@@ -956,3 +965,23 @@ class TestSelectSecret(TestCase):
 
         user_dict = BaseUser.select(exclude_secrets=True).first().run_sync()
         self.assertTrue("password" not in user_dict.keys())
+
+
+class TestSelectSecretParameter(TestCase):
+    def setUp(self):
+        Venue.create_table().run_sync()
+
+    def tearDown(self):
+        Venue.alter().drop_table().run_sync()
+
+    def test_secret_parameter(self):
+        """
+        Make sure that fields with parameter ``secret=True`` are omitted
+        from the response when requested.
+        """
+        venue = Venue(name="The Garage", capacity=1000)
+        venue.save().run_sync()
+
+        venue_dict = Venue.select(exclude_secrets=True).first().run_sync()
+        self.assertTrue(venue_dict, {"id": 1, "name": "The Garage"})
+        self.assertTrue("capacity" not in venue_dict.keys())
